@@ -40,14 +40,35 @@
 
 using namespace libmatroska;
 
+struct timecode_t {
+  int64_t m_timecode, m_duration;
+
+  timecode_t(int64_t timecode, int64_t duration)
+    : m_timecode(timecode)
+    , m_duration(duration)
+  {
+  }
+};
+
+bool
+operator <(const timecode_t &t1,
+           const timecode_t &t2) {
+  return t1.m_timecode < t2.m_timecode;
+}
+
 struct timecode_extractor_t {
-  int64_t m_tid;
+  int64_t m_tid, m_tnum;
   mm_io_cptr m_file;
-  std::vector<int64_t> m_timecodes;
+  std::vector<timecode_t> m_timecodes;
   int64_t m_default_duration;
 
-  timecode_extractor_t(int64_t tid, const mm_io_cptr &file, int64_t default_duration):
-    m_tid(tid), m_file(file), m_default_duration(default_duration) {}
+  timecode_extractor_t(int64_t tid, int64_t tnum, const mm_io_cptr &file, int64_t default_duration)
+    : m_tid(tid)
+    , m_tnum(tnum)
+    , m_file(file)
+    , m_default_duration(default_duration)
+  {
+  }
 };
 
 static std::vector<timecode_extractor_t> timecode_extractors;
@@ -57,12 +78,16 @@ static std::vector<timecode_extractor_t> timecode_extractors;
 static void
 close_timecode_files() {
   for (auto &extractor : timecode_extractors) {
-    std::vector<int64_t> &timecodes = extractor.m_timecodes;
-    std::vector<int64_t>::const_iterator timecode;
+    auto &timecodes = extractor.m_timecodes;
 
     std::sort(timecodes.begin(), timecodes.end());
     for (auto timecode : timecodes)
-      extractor.m_file->puts(to_string(timecode, 1000000, 6) + "\n");
+      extractor.m_file->puts(to_string(timecode.m_timecode, 1000000, 6) + "\n");
+
+    if (!timecodes.empty()) {
+      timecode_t &last_timecode = timecodes.back();
+      extractor.m_file->puts(to_string(last_timecode.m_timecode + last_timecode.m_duration, 1000000, 6) + "\n");
+    }
   }
 
   timecode_extractors.clear();
@@ -74,25 +99,26 @@ create_timecode_files(KaxTracks &kax_tracks,
                       int version) {
   size_t i;
   for (auto &tspec : tracks) {
-    int64_t default_duration = 0;
-
+    int track_number     = -1;
+    KaxTrackEntry *track = NULL;
     for (i = 0; kax_tracks.ListSize() > i; ++i) {
       if (!is_id(kax_tracks[i], KaxTrackEntry))
         continue;
 
-      KaxTrackEntry &track = *static_cast<KaxTrackEntry *>(kax_tracks[i]);
-
-      if (kt_get_number(track) != tspec.tid)
+      ++track_number;
+      if (track_number != tspec.tid)
         continue;
 
-      default_duration = kt_get_default_duration(track);
-      if (0 > default_duration)
-        default_duration = 0;
+      track = static_cast<KaxTrackEntry *>(kax_tracks[i]);
+      break;
     }
 
+    if (NULL == track)
+      continue;
+
     try {
       mm_io_cptr file = mm_write_buffer_io_c::open(tspec.out_name, 128 * 1024);
-      timecode_extractors.push_back(timecode_extractor_t(tspec.tid, file, default_duration));
+      timecode_extractors.push_back(timecode_extractor_t(tspec.tid, kt_get_number(*track), file, std::max(kt_get_default_duration(*track), static_cast<int64_t>(0))));
       file->puts(boost::format("# timecode format v%1%\n") % version);
 
     } catch(...) {
@@ -106,7 +132,7 @@ static
 std::vector<timecode_extractor_t>::iterator
 find_extractor_by_track_number(unsigned int track_number) {
   return std::find_if(timecode_extractors.begin(), timecode_extractors.end(),
-                      [=](timecode_extractor_t &xtr) { return track_number == xtr.m_tid; });
+                      [=](timecode_extractor_t &xtr) { return track_number == xtr.m_tnum; });
 }
 
 static void
@@ -131,7 +157,7 @@ handle_blockgroup(KaxBlockGroup &blockgroup,
   // Pass the block to the extractor.
   size_t i;
   for (i = 0; block->NumberFrames() > i; ++i)
-    extractor->m_timecodes.push_back((int64_t)(block->GlobalTimecode() + i * (double)duration / block->NumberFrames()));
+    extractor->m_timecodes.push_back(timecode_t(block->GlobalTimecode() + i * duration / block->NumberFrames(), duration / block->NumberFrames()));
 }
 
 static void
@@ -149,7 +175,7 @@ handle_simpleblock(KaxSimpleBlock &simpleblock,
   // Pass the block to the extractor.
   size_t i;
   for (i = 0; simpleblock.NumberFrames() > i; ++i)
-    extractor->m_timecodes.push_back((int64_t)(simpleblock.GlobalTimecode() + i * (double)extractor->m_default_duration));
+    extractor->m_timecodes.push_back(timecode_t(simpleblock.GlobalTimecode() + i * extractor->m_default_duration, extractor->m_default_duration));
 }
 
 void
