@@ -1559,7 +1559,7 @@ kax_reader_c::create_dts_audio_packetizer(kax_track_t *t,
     if (-1 == position)
       throw false;
 
-    set_track_packetizer(t, new dts_packetizer_c(this, nti, dtsheader, true));
+    set_track_packetizer(t, new dts_packetizer_c(this, nti, dtsheader));
     show_packetizer_info(t->tnum, t->ptzr_ptr);
 
   } catch (...) {
@@ -2278,12 +2278,23 @@ kax_reader_c::identify() {
 
     verbose_info.clear();
 
+    verbose_info.push_back((boost::format("number:%1%") % track->track_number).str());
+    verbose_info.push_back((boost::format("uid:%1%") % track->track_uid).str());
+    verbose_info.push_back((boost::format("codec_id:%1%") % escape(track->codec_id)).str());
+    verbose_info.push_back((boost::format("codec_private_length:%1%") % track->private_size).str());
+
+    if ((0 != track->private_size) && (NULL != track->private_data))
+      verbose_info.push_back((boost::format("codec_private_data:%1%") % to_hex(static_cast<const unsigned char *>(track->private_data), track->private_size, true)).str());
+
     if (track->language != "")
       verbose_info.push_back((boost::format("language:%1%") % escape(track->language)).str());
 
     if (track->track_name != "")
       verbose_info.push_back((boost::format("track_name:%1%") % escape(track->track_name)).str());
 
+    if ((0 != track->v_width) && (0 != track->v_height))
+      verbose_info.push_back((boost::format("pixel_dimensions:%1%x%2%") % track->v_width % track->v_height).str());
+
     if ((0 != track->v_dwidth) && (0 != track->v_dheight))
       verbose_info.push_back((boost::format("display_dimensions:%1%x%2%") % track->v_dwidth % track->v_dheight).str());
 
@@ -2311,6 +2322,9 @@ kax_reader_c::identify() {
         verbose_info.push_back((boost::format("audio_channels:%1%") % track->a_channels).str());
     }
 
+    if (track->content_decoder.has_encodings())
+      verbose_info.push_back((boost::format("content_encoding_algorithms:%1%") % escape(track->content_decoder.descriptive_algorithm_list())).str());
+
     std::string info = track->codec_id;
 
     if (track->ms_compat)
