@@ -20,7 +20,7 @@
 
 class he_top_level_page_c: public he_empty_page_c {
 public:
-  he_top_level_page_c(header_editor_frame_c *parent, const translatable_string_c &title, EbmlElement *l1_element);
+  he_top_level_page_c(header_editor_frame_c *parent, const translatable_string_c &title, ebml_element_cptr l1_element);
   virtual ~he_top_level_page_c();
 
   virtual void do_modifications();
